@@ -1,172 +1,5 @@
 r'''
-# aws-cloudfront-apigateway-lambda module
-
-<!--BEGIN STABILITY BANNER-->---
-
-
-![Stability: Stable](https://img.shields.io/badge/cfn--resources-stable-success.svg?style=for-the-badge)
-
----
-<!--END STABILITY BANNER-->
-
-| **Reference Documentation**:| <span style="font-weight: normal">https://docs.aws.amazon.com/solutions/latest/constructs/</span>|
-|:-------------|:-------------|
-
-<div style="height:8px"></div>
-
-| **Language**     | **Package**        |
-|:-------------|-----------------|
-|![Python Logo](https://docs.aws.amazon.com/cdk/api/latest/img/python32.png) Python|`aws_solutions_constructs.aws_cloudfront_apigateway_lambda`|
-|![Typescript Logo](https://docs.aws.amazon.com/cdk/api/latest/img/typescript32.png) Typescript|`@aws-solutions-constructs/aws-cloudfront-apigateway-lambda`|
-|![Java Logo](https://docs.aws.amazon.com/cdk/api/latest/img/java32.png) Java|`software.amazon.awsconstructs.services.cloudfrontapigatewaylambda`|
-
-## Overview
-
-This AWS Solutions Construct implements an AWS CloudFront fronting an Amazon API Gateway Lambda backed REST API.
-
-Here is a minimal deployable pattern definition:
-
-Typescript
-
-```python
-import { Construct } from 'constructs';
-import { Stack, StackProps } from 'aws-cdk-lib';
-import { CloudFrontToApiGatewayToLambda } from '@aws-solutions-constructs/aws-cloudfront-apigateway-lambda';
-import * as lambda from 'aws-cdk-lib/aws-lambda';
-
-new CloudFrontToApiGatewayToLambda(this, 'test-cloudfront-apigateway-lambda', {
-  lambdaFunctionProps: {
-    code: lambda.Code.fromAsset(`lambda`),
-    runtime: lambda.Runtime.NODEJS_20_X,
-    handler: 'index.handler'
-  },
-  apiGatewayProps: {
-    defaultMethodOptions: {
-      authorizationType: api.AuthorizationType.NONE
-    }
-  },
-});
-```
-
-Python
-
-```python
-from aws_solutions_constructs.aws_cloudfront_apigateway_lambda import CloudFrontToApiGatewayToLambda
-from aws_cdk import (
-  aws_lambda as _lambda,
-  aws_apigateway as apigw,
-  Stack
-)
-from constructs import Construct
-
-        CloudFrontToApiGatewayToLambda(
-            self, 'CloudFrontApiGatewayToLambda',
-            lambda_function_props=_lambda.FunctionProps(
-                runtime=_lambda.Runtime.PYTHON_3_11,
-                code=_lambda.Code.from_asset('lambda'),
-                handler='hello.handler',
-            ),
-            # NOTE - we use RestApiProps here because the actual type, LambdaRestApiProps requires
-            # the handler function which does not yet exist. As RestApiProps is a subset of of LambdaRestApiProps
-            # (although does not *extend* that interface) this works fine when the props object reaches the
-            # underlying TypeScript code that implements Constructs
-            api_gateway_props=apigw.RestApiProps(
-                default_method_options=apigw.MethodOptions(
-                    authorization_type=apigw.AuthorizationType.NONE
-                )
-            )
-        )
-```
-
-Java
-
-```java
-import software.constructs.Construct;
-
-import software.amazon.awscdk.Stack;
-import software.amazon.awscdk.StackProps;
-import software.amazon.awscdk.services.lambda.*;
-import software.amazon.awscdk.services.lambda.Runtime;
-import software.amazon.awsconstructs.services.cloudfrontapigatewaylambda.*;
-import software.amazon.awsconstructs.services.cloudfrontapigatewaylambda.CloudFrontToApiGatewayToLambdaProps;
-
-new CloudFrontToApiGatewayToLambda(this, "ApiGatewayToLambdaPattern", new CloudFrontToApiGatewayToLambdaProps.Builder()
-        .lambdaFunctionProps(new FunctionProps.Builder()
-                .runtime(Runtime.NODEJS_20_X) // execution environment
-                .code(Code.fromAsset("lambda")) // code loaded from the `lambda` directory (under root, next to `src`)
-                .handler("hello.handler") // file is `hello`, function is `handler`
-                .build())
-        // NOTE - we use RestApiProps here because the actual type, LambdaRestApiProps requires
-        // the handler function which does not yet exist. As RestApiProps is a subset of of LambdaRestApiProps
-        // (although does not *extend* that interface) this works fine when the props object reaches the
-        // underlying TypeScript code that implements Constructs
-        .apiGatewayProps(new RestApiProps.Builder()
-                .defaultMethodOptions(new MethodOptions.Builder()
-                        .authorizationType(AuthorizationType.NONE)
-                        .build())
-                .build())
-        .build());
-```
-
-## Pattern Construct Props
-
-| **Name**     | **Type**        | **Description** |
-|:-------------|:----------------|-----------------|
-|existingLambdaObj?|[`lambda.Function`](https://docs.aws.amazon.com/cdk/api/v2/docs/aws-cdk-lib.aws_lambda.Function.html)|Existing instance of Lambda Function object, providing both this and `lambdaFunctionProps` will cause an error.|
-|lambdaFunctionProps?|[`lambda.FunctionProps`](https://docs.aws.amazon.com/cdk/api/v2/docs/aws-cdk-lib.aws_lambda.FunctionProps.html)|Optional user provided props to override the default props for the Lambda function.|
-|apiGatewayProps?|[`api.LambdaRestApiProps`](https://docs.aws.amazon.com/cdk/api/v2/docs/aws-cdk-lib.aws_apigateway.LambdaRestApiProps.html)|User provided props to override the default props for the API Gateway. As of release 2.48.0, clients must include this property with `defaultMethodOptions: { authorizationType: string }` specified. See Issue1043 in the github repo https://github.com/awslabs/aws-solutions-constructs/issues/1043 |
-|cloudFrontDistributionProps?|[`cloudfront.DistributionProps`](https://docs.aws.amazon.com/cdk/api/v2/docs/aws-cdk-lib.aws_cloudfront.DistributionProps.html)|Optional user provided props to override the default props for CloudFront Distribution|
-|insertHttpSecurityHeaders?|`boolean`|Optional user provided props to turn on/off the automatic injection of best practice HTTP security headers in all responses from CloudFront|
-| responseHeadersPolicyProps?   | [`cloudfront.ResponseHeadersPolicyProps`](https://docs.aws.amazon.com/cdk/api/v2/docs/aws-cdk-lib.aws_cloudfront.ResponseHeadersPolicyProps.html) | Optional user provided configuration that cloudfront applies to all http responses.                                                         |
-|logGroupProps?|[`logs.LogGroupProps`](https://docs.aws.amazon.com/cdk/api/v2/docs/aws-cdk-lib.aws_logs.LogGroupProps.html)|Optional user provided props to override the default props for for the CloudWatchLogs LogGroup.|
-|cloudFrontLoggingBucketProps?|[`s3.BucketProps`](https://docs.aws.amazon.com/cdk/api/v2/docs/aws-cdk-lib.aws_s3.BucketProps.html)|Optional user provided props to override the default props for the CloudFront Logging Bucket.|
-
-## Pattern Properties
-
-| **Name**     | **Type**        | **Description** |
-|:-------------|:----------------|-----------------|
-|cloudFrontWebDistribution|[`cloudfront.Distribution`](https://docs.aws.amazon.com/cdk/api/v2/docs/aws-cdk-lib.aws_cloudfront.Distribution.html)|Returns an instance of cloudfront.Distribution created by the construct|
-|cloudFrontFunction?|[`cloudfront.Function`](https://docs.aws.amazon.com/cdk/api/v2/docs/aws-cdk-lib.aws_cloudfront.Function.html)|Returns an instance of the Cloudfront function created by the pattern.|
-|cloudFrontLoggingBucket|[`s3.Bucket`](https://docs.aws.amazon.com/cdk/api/latest/docs/aws-s3-readme.html)|Returns an instance of the logging bucket for CloudFront Distribution.|
-|apiGateway|[`api.RestApi`](https://docs.aws.amazon.com/cdk/api/v2/docs/aws-cdk-lib.aws_apigateway.RestApi.html)|Returns an instance of the API Gateway REST API created by the pattern.|
-|apiGatewayCloudWatchRole?|[`iam.Role`](https://docs.aws.amazon.com/cdk/api/v2/docs/aws-cdk-lib.aws_iam.Role.html)|Returns an instance of the iam.Role created by the construct for API Gateway for CloudWatch access.|
-|apiGatewayLogGroup|[`logs.LogGroup`](https://docs.aws.amazon.com/cdk/api/v2/docs/aws-cdk-lib.aws_logs.LogGroup.html)|Returns an instance of the LogGroup created by the construct for API Gateway access logging to CloudWatch.|
-|lambdaFunction|[`lambda.Function`](https://docs.aws.amazon.com/cdk/api/v2/docs/aws-cdk-lib.aws_lambda.Function.html)|Returns an instance of the Lambda function created by the pattern.|
-
-## Default settings
-
-Out of the box implementation of the Construct without any override will set the following defaults:
-
-### Amazon CloudFront
-
-* Configure Access logging for CloudFront Distribution
-* Enable automatic injection of best practice HTTP security headers in all responses from CloudFront Distribution
-
-### Amazon API Gateway
-
-* Deploy a regional API endpoint
-* Enable CloudWatch logging for API Gateway
-* Configure least privilege access IAM role for API Gateway
-* Set the default authorizationType for all API methods to NONE
-* Enable X-Ray Tracing
-
-### AWS Lambda Function
-
-* Configure limited privilege access IAM role for Lambda function
-* Enable reusing connections with Keep-Alive for NodeJs Lambda function
-* Enable X-Ray Tracing
-* Set Environment Variables
-
-  * AWS_NODEJS_CONNECTION_REUSE_ENABLED (for Node 10.x and higher functions)
-
-## Architecture
-
-![Architecture Diagram](architecture.png)
-
----
-
-
-© Copyright Amazon.com, Inc. or its affiliates. All Rights Reserved.
+Documentation for this pattern can be found [here](https://github.com/awslabs/aws-solutions-constructs/blob/main/source/patterns/%40aws-solutions-constructs/aws-cloudfront-apigateway-lambda/README.adoc)
 '''
 from pkgutil import extend_path
 __path__ = extend_path(__path__, __name__)
@@ -222,6 +55,7 @@ class CloudFrontToApiGatewayToLambda(
         api_gateway_props: typing.Any,
         cloud_front_distribution_props: typing.Any = None,
         cloud_front_logging_bucket_props: typing.Optional[typing.Union[_aws_cdk_aws_s3_ceddda9d.BucketProps, typing.Dict[builtins.str, typing.Any]]] = None,
+        create_usage_plan: typing.Optional[builtins.bool] = None,
         existing_lambda_obj: typing.Optional[_aws_cdk_aws_lambda_ceddda9d.Function] = None,
         insert_http_security_headers: typing.Optional[builtins.bool] = None,
         lambda_function_props: typing.Optional[typing.Union[_aws_cdk_aws_lambda_ceddda9d.FunctionProps, typing.Dict[builtins.str, typing.Any]]] = None,
@@ -234,6 +68,7 @@ class CloudFrontToApiGatewayToLambda(
         :param api_gateway_props: User provided props to override the default props for the API Gateway. As of release 2.48.0, clients must include this property with defaultMethodOptions: { authorizationType: string } specified. See Issue1043 in the github repo https://github.com/awslabs/aws-solutions-constructs/issues/1043 Default: - defaultMethodOptions/authorizationType is required, for other, unspecified values the default props are used
         :param cloud_front_distribution_props: Optional user provided props to override the default props. Default: - Default props are used
         :param cloud_front_logging_bucket_props: Optional user provided props to override the default props for the CloudFront Logging Bucket. Default: - Default props are used
+        :param create_usage_plan: Whether to create a Usage Plan attached to the API. Must be true if apiGatewayProps.defaultMethodOptions.apiKeyRequired is true Default: - true (to match legacy behavior)
         :param existing_lambda_obj: Existing instance of Lambda Function object, providing both this and ``lambdaFunctionProps`` will cause an error. Default: - None
         :param insert_http_security_headers: Optional user provided props to turn on/off the automatic injection of best practice HTTP security headers in all responses from cloudfront. Turning this on will inject default headers and is mutually exclusive with passing custom security headers via the responseHeadersPolicyProps parameter. Default: - true
         :param lambda_function_props: Optional user provided props to override the default props for the Lambda function. Default: - Default props are used
@@ -252,6 +87,7 @@ class CloudFrontToApiGatewayToLambda(
             api_gateway_props=api_gateway_props,
             cloud_front_distribution_props=cloud_front_distribution_props,
             cloud_front_logging_bucket_props=cloud_front_logging_bucket_props,
+            create_usage_plan=create_usage_plan,
             existing_lambda_obj=existing_lambda_obj,
             insert_http_security_headers=insert_http_security_headers,
             lambda_function_props=lambda_function_props,
@@ -312,6 +148,7 @@ class CloudFrontToApiGatewayToLambda(
         "api_gateway_props": "apiGatewayProps",
         "cloud_front_distribution_props": "cloudFrontDistributionProps",
         "cloud_front_logging_bucket_props": "cloudFrontLoggingBucketProps",
+        "create_usage_plan": "createUsagePlan",
         "existing_lambda_obj": "existingLambdaObj",
         "insert_http_security_headers": "insertHttpSecurityHeaders",
         "lambda_function_props": "lambdaFunctionProps",
@@ -326,6 +163,7 @@ class CloudFrontToApiGatewayToLambdaProps:
         api_gateway_props: typing.Any,
         cloud_front_distribution_props: typing.Any = None,
         cloud_front_logging_bucket_props: typing.Optional[typing.Union[_aws_cdk_aws_s3_ceddda9d.BucketProps, typing.Dict[builtins.str, typing.Any]]] = None,
+        create_usage_plan: typing.Optional[builtins.bool] = None,
         existing_lambda_obj: typing.Optional[_aws_cdk_aws_lambda_ceddda9d.Function] = None,
         insert_http_security_headers: typing.Optional[builtins.bool] = None,
         lambda_function_props: typing.Optional[typing.Union[_aws_cdk_aws_lambda_ceddda9d.FunctionProps, typing.Dict[builtins.str, typing.Any]]] = None,
@@ -336,6 +174,7 @@ class CloudFrontToApiGatewayToLambdaProps:
         :param api_gateway_props: User provided props to override the default props for the API Gateway. As of release 2.48.0, clients must include this property with defaultMethodOptions: { authorizationType: string } specified. See Issue1043 in the github repo https://github.com/awslabs/aws-solutions-constructs/issues/1043 Default: - defaultMethodOptions/authorizationType is required, for other, unspecified values the default props are used
         :param cloud_front_distribution_props: Optional user provided props to override the default props. Default: - Default props are used
         :param cloud_front_logging_bucket_props: Optional user provided props to override the default props for the CloudFront Logging Bucket. Default: - Default props are used
+        :param create_usage_plan: Whether to create a Usage Plan attached to the API. Must be true if apiGatewayProps.defaultMethodOptions.apiKeyRequired is true Default: - true (to match legacy behavior)
         :param existing_lambda_obj: Existing instance of Lambda Function object, providing both this and ``lambdaFunctionProps`` will cause an error. Default: - None
         :param insert_http_security_headers: Optional user provided props to turn on/off the automatic injection of best practice HTTP security headers in all responses from cloudfront. Turning this on will inject default headers and is mutually exclusive with passing custom security headers via the responseHeadersPolicyProps parameter. Default: - true
         :param lambda_function_props: Optional user provided props to override the default props for the Lambda function. Default: - Default props are used
@@ -357,6 +196,7 @@ class CloudFrontToApiGatewayToLambdaProps:
             check_type(argname="argument api_gateway_props", value=api_gateway_props, expected_type=type_hints["api_gateway_props"])
             check_type(argname="argument cloud_front_distribution_props", value=cloud_front_distribution_props, expected_type=type_hints["cloud_front_distribution_props"])
             check_type(argname="argument cloud_front_logging_bucket_props", value=cloud_front_logging_bucket_props, expected_type=type_hints["cloud_front_logging_bucket_props"])
+            check_type(argname="argument create_usage_plan", value=create_usage_plan, expected_type=type_hints["create_usage_plan"])
             check_type(argname="argument existing_lambda_obj", value=existing_lambda_obj, expected_type=type_hints["existing_lambda_obj"])
             check_type(argname="argument insert_http_security_headers", value=insert_http_security_headers, expected_type=type_hints["insert_http_security_headers"])
             check_type(argname="argument lambda_function_props", value=lambda_function_props, expected_type=type_hints["lambda_function_props"])
@@ -369,6 +209,8 @@ class CloudFrontToApiGatewayToLambdaProps:
             self._values["cloud_front_distribution_props"] = cloud_front_distribution_props
         if cloud_front_logging_bucket_props is not None:
             self._values["cloud_front_logging_bucket_props"] = cloud_front_logging_bucket_props
+        if create_usage_plan is not None:
+            self._values["create_usage_plan"] = create_usage_plan
         if existing_lambda_obj is not None:
             self._values["existing_lambda_obj"] = existing_lambda_obj
         if insert_http_security_headers is not None:
@@ -417,6 +259,18 @@ class CloudFrontToApiGatewayToLambdaProps:
         result = self._values.get("cloud_front_logging_bucket_props")
         return typing.cast(typing.Optional[_aws_cdk_aws_s3_ceddda9d.BucketProps], result)
 
+    @builtins.property
+    def create_usage_plan(self) -> typing.Optional[builtins.bool]:
+        '''Whether to create a Usage Plan attached to the API.
+
+        Must be true if
+        apiGatewayProps.defaultMethodOptions.apiKeyRequired is true
+
+        :default: - true (to match legacy behavior)
+        '''
+        result = self._values.get("create_usage_plan")
+        return typing.cast(typing.Optional[builtins.bool], result)
+
     @builtins.property
     def existing_lambda_obj(
         self,
@@ -506,6 +360,7 @@ def _typecheckingstub__461316ff0e3f859e7f9f591a5b92a85dedccc24c1704e2e7c328642bf
     api_gateway_props: typing.Any,
     cloud_front_distribution_props: typing.Any = None,
     cloud_front_logging_bucket_props: typing.Optional[typing.Union[_aws_cdk_aws_s3_ceddda9d.BucketProps, typing.Dict[builtins.str, typing.Any]]] = None,
+    create_usage_plan: typing.Optional[builtins.bool] = None,
     existing_lambda_obj: typing.Optional[_aws_cdk_aws_lambda_ceddda9d.Function] = None,
     insert_http_security_headers: typing.Optional[builtins.bool] = None,
     lambda_function_props: typing.Optional[typing.Union[_aws_cdk_aws_lambda_ceddda9d.FunctionProps, typing.Dict[builtins.str, typing.Any]]] = None,
@@ -520,6 +375,7 @@ def _typecheckingstub__ce72cd5951b6f82c649ba294f738b5af3f429f19b161a863f8dc35b18
     api_gateway_props: typing.Any,
     cloud_front_distribution_props: typing.Any = None,
     cloud_front_logging_bucket_props: typing.Optional[typing.Union[_aws_cdk_aws_s3_ceddda9d.BucketProps, typing.Dict[builtins.str, typing.Any]]] = None,
+    create_usage_plan: typing.Optional[builtins.bool] = None,
     existing_lambda_obj: typing.Optional[_aws_cdk_aws_lambda_ceddda9d.Function] = None,
     insert_http_security_headers: typing.Optional[builtins.bool] = None,
     lambda_function_props: typing.Optional[typing.Union[_aws_cdk_aws_lambda_ceddda9d.FunctionProps, typing.Dict[builtins.str, typing.Any]]] = None,
